Petscii
=======

Petscii is a tiny PHP library which converts text to PETSCII (PET Standard Code of Information Interchange) format, a character set based on ASCII. 
It has been used in Commodore Business Machines - the 8-bit home
computers like VIC-20, C64, C128, CBM-II, Commodore Plus/4, C16 and C116.

With this package, you can prepare your website to be fully compatible with web browsers available for Commodore 64 or
Commodore 128 connected to internet via one of existing ethernet cartridges: _64NIC+_, _The Final Ethernet_,
_RR-Net_ or other. You can even surf the web using an emulator.

This package is used on [www.commocore.com](http://www.commocore.com) website.


Supported browsers
==================

Petscii package has been tested on a few Commodore 64 browsers. Please let me know if you're using other ones,
or you've encountered any issues. Also, please let me know if some of the links below are no longer available.

Contiki web browser
-------------------
Online HTML web browser available with a web server and other tools.
Set up disk configurator for version 2.5 available [here](http://contiki.cbm8bit.com).
_Contiki 3_ is available [here](http://retrohackers.com/viewtopic.php?f=5&t=669).

Singular browser
----------------
Online HTML web browser. About the browser [here](http://singularcrew.hu/browser/). Set up disk available
[here](http://home.sch.bme.hu/~soci64/browser/compile.php).

HyperLink
---------
Online HTML web browser. Not tested yet, but detected by PETSCII. More info [here](http://www.armory.com/~spectre/cwi/hl/manual/index.html).

FairlightML
-----------
Offline HTML viewer also known as _64'er htmlreader_. Version 0.99 is available
[here](http://commodore.software/downloads/download/151-miscellaneous-applications/1050-fairlightml-v0-99.html).
You can download files using WGET (available i.a. on _Contiki_ floppy disk).


Entering World Wide Web with emulator
=====================================

If you don't have physical ethernet card, you can try [Vice64 emulator](http://vice-emu.sourceforge.net) for Windows (with
[WinPcap](http://winpcap.org/install/default.htm) installed). You will find details in this
[Commodore Server blog entry](http://www.commodoreserver.com/BlogEntryView.asp?EID=CDB68A9028654CCEA758D37C6DB3E05B).


Features
========

- All non-ASCII characters are converted to basic ASCII-96
- Can detect if browser is running in PETSCII mode (HTTP user agent check)
- Pound Sterling character will be converted to the responding PETSCII character `CHR$(92)` for _Contiki_ browser
- All variations of break line tag (e.g. `<br />`) will be converted to `<br>` ( _FairlightML_ browser cannot detect other variations)


Installation
============

To install via Composer, just:

    composer require commocore/petscii

This package uses Composer autoloader, regular boot looks this way (for more details, see Composer documentation):
 
    require_once '../vendor/autoload.php';

And can be imported this way:

    use Commocore\Petscii\Petscii;


Usage
=====

    $content = 'Commodore 64<br />The Commodore 64 is an 8-bit home computer introduced in January 1982.<br />';
    
    $petscii = new Petscii();
    $content = $petscii->render($content);
    
    echo $content;

As you see, you don't have to check if browser supports PETSCII. HTTP user agent is recognized automatically,
and if a browser doesn't support PETSCII, text content will be displayed without any changes.


To trim break lines (or other characters), just provide them in string as the second parameter (uses PHP's `trim()` mask):

    $content = $petscii->render($content, '<br>');


Note: you don't have to define other variations of `<br>` in trim mask (e.g. `<br />`) as all variations of
break line will be converted to `<br>` by default.


To check if browser is supporting PETSCII:

    if ($petscii->isPetsciiBrowser()) {
        // I'm PETSCII!
    }


To return browser class detected by HTTP user agent:

    $browserClass = $petscii->getDetectedBrowser();
    
Or, to get only the class name (without namespace):

    $className = substr(strrchr(get_class($petscii->getDetectedBrowser()), "\\"), 1);


Testing the package
===================

Docker (with Docker Compose) has been used for testing purposes.

Setup
-----

1. First, you need to build images by executing `make build`.
2. Then, you can execute `make all` in the main directory for the first time to install PHP dependencies and
run containers, or use `make composer` then `make start`.

Executing tests
---------------

You will find all available _make_ commands in _Makefile_. To test the whole project just `make test`.
For the test coverage, if `make phpunit-code-coverage-html` is used, results will be saved to `coverage/`
folder in the HTML format.

Testing available characters
----------------------------

To see characters available in a particular browser, you can create test page where you can generate list of all 256 characters this way:

    echo $petscii->getTestPage();


Notes
=====

Underscore character compatibility
----------------------------------
As _Contiki_ browser is not using underscore character (instead left arrow `CHR$(95)` is displayed), and there is no
equivalent available for this browser, you can ignore it, or remove underscores from text beforehand.
This character is fully supported e.g. in _FairlightML_ HTML viewer and _Singular browser_.
