<?php

namespace Commocore\Tests;

use PHPUnit_Framework_TestCase;
use Commocore\Petscii\Petscii;

class SingularBrowserTest extends PHPUnit_Framework_TestCase
{
    /**
     * @var Petscii
     */
    private $petscii;

    public function setUp()
    {
        $_SERVER['HTTP_USER_AGENT'] = 'Singular/0.52 (Commodore 64)';
        $this->petscii = new Petscii();
    }

    /**
     * @dataProvider data
     * @param string $content
     */
    public function testTrimMask($content)
    {
        $expectedContent = 'The Commodore 64 is an 8-bit home computer introduced in January 1982.';

        $content = $this->petscii->render($content, '<br /><br>');
        $this->assertEquals($expectedContent, $content);
    }

    /**
     * Contiki supports Pound Sterling character, but Singular Browser
     * will display backslash for chr(92) so do nothing here
     * Transliterator will return "PS"
     *
     * @dataProvider poundSterlingStringData
     * @param string $content
     */
    public function testNotSupportedPoundSterlingCharacter($content)
    {
        $expectedContent = 'Commodore 64 costs only PS360 now!';

        $content = $this->petscii->render($content);
        $this->assertEquals($expectedContent, $content);
    }

    /**
     * @dataProvider citiesData
     * @param string $content
     * @param string $expectedContent
     */
    public function testCharacters($content, $expectedContent)
    {
        $content = $this->petscii->render($content, '<br /><br>');
        $this->assertEquals($expectedContent, $content);
    }

    /**
     * @return array
     */
    public function data()
    {
        return array(
            array(
                '<br /><BR />The Commodore 64 is an 8-bit home computer introduced in January 1982.<br  /><br>'
            )
        );
    }

    /**
     * @return array
     */
    public function poundSterlingStringData()
    {
        return array(
            array(
                'Commodore 64 costs only £360 now!'
            )
        );
    }

    /**
     * @return array
     */
    public function citiesData()
    {
        return array(
            array(
                'Köln',
                'Koln'
            ),
            array(
                'Reykjavík',
                'Reykjavik'
            ),
            array(
                'Łódź',
                'Lodz'
            ),
            array(
                'Санкт-Петербург',
                'Sankt-Pietierburgh'
            ),
            array(
                'São Paulo',
                'Sao Paulo'
            ),
            array(
                'Olhão da Restauração',
                'Olhao da Restauracao'
            )
        );
    }
}
